
local C = require("classic")

-- Resource helper functions

function gfx(name, ofx, ofy, s1, s2)
   return kts.Graphic("gfx/" .. name .. ".bmp", 255,255,0, ofx,ofy, s1,s2)
end

function anim(name, of, s1, s2)
   return kts.Anim { 
            gfx(name .. "1n",    of,    of, s1,s2), -- Normal
            gfx(name .. "1e",    of,    of, s1,s2),
            gfx(name .. "1s",    of,    of, s1,s2),
            gfx(name .. "1w",    of,    of, s1,s2),
            gfx(name .. "2n",    of,    of, s1,s2), -- Melee backswing
            gfx(name .. "2e",    of,    of, s1,s2),
            gfx(name .. "2s",    of,    of, s1,s2),
            gfx(name .. "2w",    of,    of, s1,s2),
            gfx(name .. "3n",    of, 16+of, s1,s2), -- Melee downswing
            gfx(name .. "3e",    of,    of, s1,s2),
            gfx(name .. "3s",    of,    of, s1,s2),
            gfx(name .. "3w", 16+of,    of, s1,s2),
            gfx(name .. "4n",    of,    of, s1,s2), -- Just Hit.
            gfx(name .. "4e",    of,    of, s1,s2),
            gfx(name .. "4s",    of,    of, s1,s2),
            gfx(name .. "4w",    of,    of, s1,s2)
          }
end

function tile(name, of, s1, s2)
   local g_tile = gfx(name, of,of, s1,s2)
   return kts.Tile(C.floor & { graphic=g_tile, depth = -1 })
end

-- Normal spider
a_spider1 = anim("spid",        -3, 4,3) -- Animation
t_spider1 = tile("dead_spider", -3, 4,3) -- Death tile

-- Smaller spider
a_spider2 = anim("spid",        -8, 2,1) -- Animation
t_spider2 = tile("dead_spider", -8, 2,1) -- Death tile

-- Big spider
a_spider3 = anim("spid",        0, 1,1) -- Animation
t_spider3 = tile("dead_spider", 0, 1,1) -- Death tile


--- Sounds
--s_spider = kts.Sound("snd/spider.wav") --Todo

function snd_spider() 
   --kts.PlaySound(cxt.pos, s_spider, 15000) --Todo
end

---- Weapon and Monster Type

basic_spider_weapon = {
   -- Something beetween sword and axe;
   -- Barely any tile damage.
   type = "held",
   melee_backswing_time = 2*C.ts,
   melee_downswing_time = 3*C.ts,
   melee_damage         = C.rng_range(1,2),
   melee_stun_time      = C.rng_time_range(2,3),
   melee_tile_damage    = 1
}   

-- Normal spider
i_spider_weap1 = kts.ItemType( basic_spider_weapon )

-- Small spider
i_spider_weap2 = kts.ItemType( basic_spider_weapon & { 
   melee_damage         = 1,
   melee_stun_time      = C.rng_time_range(0,1),
   melee_tile_damage    = 0
} )

-- Big spider
i_spider_weap3 = kts.ItemType( basic_spider_weapon & { 
   melee_damage         = C.rng_range(1,3),
   melee_stun_time      = C.rng_time_range(3,5),
   melee_tile_damage    = 2
} )



basic_spider = {
   type = "walking",

   -- general properties:
   health = C.rng_range(1, 4),    -- somewhere beetween zombies and bats
   speed = 76,                  -- faster than zombies, but slower than bats
   anim = a_spider1,
   corpse_tiles = { t_spider1 },
   sound = snd_spider, -- No actual sound yet

   -- properties specific to walking monsters:
   weapon = i_spider_weap1,

   -- list of tiles that spiders don't want to walk onto:
   ai_avoid = C.all_open_pit_tiles
}

-- Normal spiders
m_spider1 = kts.MonsterType( basic_spider & { anim = a_spider1, corpse_tiles = {t_spider1} } )

-- Small spiders
m_spider2 = kts.MonsterType( basic_spider & { anim = a_spider2, corpse_tiles = {t_spider2},
   weapon = i_spider_weap2,
   health = C.rng_range(1, 2), -- same as bats
   speed = 81 -- faster than normal spider, but slower than bat
} )

-- Big spiders
m_spider3 = kts.MonsterType( basic_spider & { anim = a_spider3, corpse_tiles = {t_spider3}, 
   weapon = i_spider_weap3,
   health = C.rng_range(3, 6) -- pretty tough
} )

spiders = { m_spider1,  -- 1
            m_spider2,  -- 2
            m_spider3 } -- 3

-- These numbers correspond to spiders table indexes
spider_chances = { 1, 1, 1, 1, 2, 2, 2, 3 }

----


